@@ -83,7 +83,9 @@ class SolumClient(rest_client.RestClient):
         self.created_apps = []
         self.created_lps = []
 
-    def request_without_auth(self, resource, method, headers={}, body=None):
+    def request_without_auth(self, resource, method, headers=None, body=None):
+        if headers is None:
+            headers = {}
         dscv = CONF.identity.disable_ssl_certificate_validation
         http_obj = http.ClosingHttp(disable_ssl_certificate_validation=dscv)
         url = '%s/%s' % (self.base_url, resource)
@@ -239,9 +241,9 @@ class SolumCredentials(auth.KeystoneV2Credentials):
 
     def __init__(self):
         creds = dict(
-            username=CONF.identity.username,
-            password=CONF.identity.password,
-            tenant_name=CONF.identity.project_name
+            username=CONF.auth.admin_username,
+            password=CONF.auth.admin_password,
+            tenant_name=CONF.auth.admin_project_name
         )
 
         super(SolumCredentials, self).__init__(**creds)
