@@ -14,32 +14,37 @@
 
 """Solum Deployer Heat handler."""
 
+import json
 import logging
 import socket
 import time
 
 from heatclient import exc
 import httplib2
+from keystoneclient.v2_0 import client as ksclient
 from oslo_config import cfg
+from oslo_log import log as os_logging
 import six
 from sqlalchemy import exc as sqla_exc
 from swiftclient import exceptions as swiftexp
 import yaml
 
+import solum
 from solum.api.handlers import userlog_handler
 from solum.common import catalog
 from solum.common import clients
 from solum.common import exception
 from solum.common import heat_utils
 from solum.common import repo_utils
+from solum.common import solum_glanceclient
 from solum.common import solum_swiftclient
+from solum.common import utils
 from solum import objects
 from solum.objects import assembly
-from solum.openstack.common import log as openstack_logger
 from solum.uploaders import tenant_logger as tlog
 
 
-LOG = openstack_logger.getLogger(__name__)
+LOG = os_logging.getLogger(__name__)
 
 STATES = assembly.States
 
@@ -69,6 +74,9 @@ SERVICE_OPTS = [
     cfg.StrOpt('image',
                default="coreos",
                help='Image id'),
+    cfg.StrOpt('key_name',
+               default="mykey",
+               help='keypair name'),
     cfg.StrOpt('deployer_log_dir',
                default="/var/log/solum/deployer",
                help='Deployer logs location'),
@@ -83,10 +91,37 @@ cfg.CONF.register_opts(SERVICE_OPTS, group='deployer')
 cfg.CONF.import_opt('image_format', 'solum.api.handlers.assembly_handler',
                     group='api')
 cfg.CONF.import_opt('image_storage', 'solum.worker.config', group='worker')
+cfg.CONF.import_opt('auth_uri', 'keystonemiddleware.auth_token',
+                    group='keystone_authtoken')
+
 
 deployer_log_dir = cfg.CONF.deployer.deployer_log_dir
 
 
+def get_heat_client(ctxt, app):
+    raw_content = json.loads(app.raw_content)
+    username = raw_content['username']
+    encoded_password = raw_content['password'].encode('ISO-8859-1')
+    decrypted_password = utils.decrypt(encoded_password)
+    password = decrypted_password
+    tenant_name = raw_content['tenant_name']
+    auth_url = cfg.CONF.keystone_authtoken.auth_uri
+
+    ks_kwargs = {
+        'username': username,
+        'password': password,
+        'tenant_name': tenant_name,
+        'auth_url': auth_url
+    }
+
+    k_client = ksclient.Client(**ks_kwargs)
+    auth_token = k_client.auth_token
+
+    osc = clients.OpenStackClients(ctxt)
+    heat = osc.heat(username, password, auth_token)
+    return heat
+
+
 def save_du_ref_for_scaling(ctxt, assembly_id, du=None):
 
     try:
@@ -114,6 +149,18 @@ def save_du_ref_for_scaling(ctxt, assembly_id, du=None):
             LOG.exception(ex)
 
 
+def get_assembly_by_id(ctxt, assembly_id):
+    return solum.objects.registry.Assembly.get_by_id(ctxt, assembly_id)
+
+
+def get_app_by_assem_id(ctxt, assembly_id):
+    assem = get_assembly_by_id(ctxt, assembly_id)
+    if assem:
+        plan = solum.objects.registry.Plan.get_by_id(ctxt, assem.plan_id)
+        app = solum.objects.registry.App.get_by_id(ctxt, plan.uuid)
+        return app
+
+
 def update_wf_and_app(ctxt, assembly_id, data):
     # Update workflow and app objects
     data_dict = dict()
@@ -179,9 +226,46 @@ class Handler(object):
         return ''.join([assem_name[:min(len(assem_name), prefix_len)], '-',
                         assembly.uuid])
 
-    def _delete_app_artifacts_from_swift(self, ctxt, t_logger,
-                                         logs_resource_id, assem):
-        # Delete image file from swift
+    def _clean_up_artifacts(self, ctxt, t_logger,
+                            logs_resource_id, assem):
+        try:
+            if cfg.CONF.worker.image_storage == 'swift':
+                self._delete_app_artifacts_from_swift(ctxt, t_logger,
+                                                      assem)
+            elif cfg.CONF.worker.image_storage == 'glance':
+                self._delete_app_artifacts_from_glance(ctxt, t_logger,
+                                                       assem)
+            else:
+                LOG.debug("image_storage option %s not recognized." %
+                          cfg.CONF.worker.image_storage)
+        except Exception as e:
+            LOG.exception(e)
+
+        # Delete logs
+        try:
+            log_handler = userlog_handler.UserlogHandler(ctxt)
+            log_handler.delete(logs_resource_id)
+        except exception.AuthorizationFailure as authexcp:
+            t_logger.log(logging.ERROR, six.text_type(authexcp))
+            LOG.debug(six.text_type(authexcp))
+            t_logger.upload()
+
+    def _delete_app_artifacts_from_glance(self, ctxt, t_logger, assem):
+        if assem.image_id:
+            img = objects.registry.Image.get_by_id(ctxt, assem.image_id)
+            if img.external_ref:
+                try:
+                    glance = solum_glanceclient.GlanceClient(ctxt)
+                    glance.delete_image_by_id(img.external_ref)
+                except swiftexp.ClientException:
+                    msg = "Unable to delete DU image from glance."
+                    t_logger.log(logging.ERROR, msg)
+                    LOG.debug(msg)
+                    t_logger.upload()
+                    return
+            img.destroy(ctxt)
+
+    def _delete_app_artifacts_from_swift(self, ctxt, t_logger, assem):
         if assem.image_id:
             img = objects.registry.Image.get_by_id(ctxt, assem.image_id)
             if img.docker_image_name:
@@ -197,19 +281,15 @@ class Handler(object):
                     return
             img.destroy(ctxt)
 
-        # Delete logs
-        try:
-            log_handler = userlog_handler.UserlogHandler(ctxt)
-            log_handler.delete(logs_resource_id)
-        except exception.AuthorizationFailure as authexcp:
-            t_logger.log(logging.ERROR, six.text_type(authexcp))
-            LOG.debug(six.text_type(authexcp))
-            t_logger.upload()
-
     def destroy_assembly(self, ctxt, assem_id):
         update_assembly(ctxt, assem_id,
                         {'status': STATES.DELETING})
+
         assem = objects.registry.Assembly.get_by_id(ctxt, assem_id)
+
+        app_obj = get_app_by_assem_id(ctxt, assem.id)
+        LOG.debug("Deleting app %s" % app_obj.name)
+
         logs_resource_id = assem.uuid
         stack_id = self._find_id_if_stack_exists(assem)
         try:
@@ -231,29 +311,29 @@ class Handler(object):
                                      workflow_id,
                                      deployer_log_dir,
                                      'delete')
-        msg = "Deleting Assembly %s" % assem.uuid
+        msg = "Deleting Assembly %s Workflow %s" % (assem.uuid, workflow_id)
         t_logger.log(logging.DEBUG, msg)
         LOG.debug(msg)
 
         if stack_id is None:
             t_logger.upload()
-            self._delete_app_artifacts_from_swift(ctxt, t_logger,
-                                                  logs_resource_id, assem)
+            self._clean_up_artifacts(ctxt, t_logger, logs_resource_id, assem)
             if not wf_found:
                 assem.destroy(ctxt)
             return
         else:
-            osc = clients.OpenStackClients(ctxt)
+            # Get the heat client
+            heat_clnt = get_heat_client(ctxt, app_obj)
             try:
                 t_logger.log(logging.DEBUG, "Deleting Heat stack.")
                 LOG.debug("Deleting Heat stack %s", stack_id)
-                osc.heat().stacks.delete(stack_id)
+                heat_clnt.stacks.delete(stack_id)
             except exc.HTTPNotFound:
                 # stack already deleted
                 t_logger.log(logging.ERROR, "Heat stack not found.")
                 t_logger.upload()
-                self._delete_app_artifacts_from_swift(ctxt, t_logger,
-                                                      logs_resource_id, assem)
+                self._clean_up_artifacts(ctxt, t_logger, logs_resource_id,
+                                         assem)
                 if not wf_found:
                     assem.destroy(ctxt)
                 return
@@ -272,13 +352,12 @@ class Handler(object):
             for count in range(cfg.CONF.deployer.max_attempts):
                 try:
                     # Must use stack_name for expecting a 404
-                    osc.heat().stacks.get(stack_name)
+                    heat_clnt.stacks.get(stack_name)
                 except exc.HTTPNotFound:
                     t_logger.log(logging.DEBUG, "Stack delete successful.")
                     t_logger.upload()
-                    self._delete_app_artifacts_from_swift(ctxt, t_logger,
-                                                          logs_resource_id,
-                                                          assem)
+                    self._clean_up_artifacts(ctxt, t_logger, logs_resource_id,
+                                             assem)
                     if not wf_found:
                         assem.destroy(ctxt)
                     return
@@ -291,7 +370,7 @@ class Handler(object):
             t_logger.log(logging.ERROR, "Error deleting heat stack.")
             t_logger.upload()
 
-    def _destroy_other_assemblies(self, ctxt, assembly_id):
+    def _destroy_other_assemblies(self, ctxt, assembly_id, heat_clnt):
         # Except current app's stack, destroy all other app stacks
 
         # We query the newly deployed assembly's object here to
@@ -300,26 +379,27 @@ class Handler(object):
         # that the attribute does not have the most up-to-date value due to the
         # possibility that SQLAlchemy might not synchronize object's db state
         # with its in-memory representation.
+
         new_assembly = objects.registry.Assembly.get_by_id(ctxt, assembly_id)
 
         # Fetch all assemblies by plan id, and self.destroy() them.
         new_assem_id = new_assembly.id
         app_id = new_assembly.plan_id
         created_at = new_assembly.created_at
-        assemblies = objects.registry.AssemblyList.get_earlier(new_assem_id,
-                                                               app_id,
-                                                               STATES.READY,
-                                                               created_at)
+        assemblies = objects.registry.AssemblyList.get_earlier(
+            new_assem_id,
+            app_id,
+            STATES.DEPLOYMENT_COMPLETE,
+            created_at)
         for assem in assemblies:
             if assem.id == new_assembly.id:
                 continue
 
             # Just delete the old heat stacks and don't delete assemblies
             stack_id = self._find_id_if_stack_exists(assem)
-            osc = clients.OpenStackClients(ctxt)
             try:
                 LOG.debug("Deleting Heat stack %s", stack_id)
-                osc.heat().stacks.delete(stack_id)
+                heat_clnt.stacks.delete(stack_id)
             except exc.HTTPNotFound:
                 # stack already deleted
                 LOG.debug("Heat stack not found %s", stack_id)
@@ -335,7 +415,7 @@ class Handler(object):
             for count in range(cfg.CONF.deployer.max_attempts):
                 try:
                     # Must use stack_name for expecting a 404
-                    osc.heat().stacks.get(stack_name)
+                    heat_clnt.stacks.get(stack_name)
                 except exc.HTTPNotFound:
                     LOG.debug("Heat stack deleted %s", stack_id)
                     continue
@@ -354,7 +434,10 @@ class Handler(object):
             self.destroy_assembly(ctxt, assemblie.id)
 
         # Delete workflow based on app_id
-        objects.registry.Workflow.destroy(app_id)
+        try:
+            objects.registry.Workflow.destroy(app_id)
+        except Exception:
+            LOG.error("Workflow for app %s not found ", app_id)
 
         # Delete app
         try:
@@ -369,8 +452,18 @@ class Handler(object):
         raise exception.NotImplemented()
 
     def deploy(self, ctxt, assembly_id, image_loc, image_name, ports):
+
+        app_obj = get_app_by_assem_id(ctxt, assembly_id)
+
+        LOG.debug("Deploying app %s" % app_obj.name)
+
         save_du_ref_for_scaling(ctxt, assembly_id, du=image_loc)
 
+        # Get the heat client
+        heat_clnt = get_heat_client(ctxt, app_obj)
+
+        # Get reference to OpenStackClients as it is used to get a reference
+        # to neutron client for getting networking parameters
         osc = clients.OpenStackClients(ctxt)
 
         assem = objects.registry.Assembly.get_by_id(ctxt,
@@ -417,10 +510,10 @@ class Handler(object):
 
         if stack_id is not None:
             try:
-                osc.heat().stacks.update(stack_id,
-                                         stack_name=stack_name,
-                                         template=template,
-                                         parameters=parameters)
+                heat_clnt.stacks.update(stack_id,
+                                        stack_name=stack_name,
+                                        template=template,
+                                        parameters=parameters)
 
             except Exception as e:
                 LOG.error("Error updating Heat Stack for,"
@@ -448,10 +541,10 @@ class Handler(object):
                 get_file_dict = {}
                 get_file_dict[getfile_key] = file_cnt
 
-                created_stack = osc.heat().stacks.create(stack_name=stack_name,
-                                                         template=template,
-                                                         parameters=parameters,
-                                                         files=get_file_dict)
+                created_stack = heat_clnt.stacks.create(stack_name=stack_name,
+                                                        template=template,
+                                                        parameters=parameters,
+                                                        files=get_file_dict)
             except Exception as exp:
                 LOG.error("Error creating Heat Stack for,"
                           " assembly %s" % assembly_id)
@@ -481,12 +574,12 @@ class Handler(object):
                 return
         update_assembly(ctxt, assembly_id, {'status': STATES.DEPLOYING})
 
-        result = self._check_stack_status(ctxt, assembly_id, osc, stack_id,
-                                          ports, t_logger)
+        result = self._check_stack_status(ctxt, assembly_id, heat_clnt,
+                                          stack_id, ports, t_logger)
         assem.status = result
         t_logger.upload()
-        if result == STATES.READY:
-            self._destroy_other_assemblies(ctxt, assembly_id)
+        if result == STATES.DEPLOYMENT_COMPLETE:
+            self._destroy_other_assemblies(ctxt, assembly_id, heat_clnt)
 
     def _get_template(self, ctxt, image_format, image_storage,
                       image_loc, image_name, assem, ports, t_logger):
@@ -550,6 +643,7 @@ class Handler(object):
         elif image_format == 'vm':
             parameters = {'name': str(assem.uuid),
                           'flavor': cfg.CONF.deployer.flavor,
+                          'key_name': cfg.CONF.deployer.key_name,
                           'image': cfg.CONF.deployer.image}
             ports_str = ''
             for port in ports:
@@ -565,8 +659,8 @@ class Handler(object):
             t_logger.upload()
         return parameters
 
-    def _check_stack_status(self, ctxt, assembly_id, osc, stack_id, ports,
-                            t_logger):
+    def _check_stack_status(self, ctxt, assembly_id, heat_clnt, stack_id,
+                            ports, t_logger):
 
         wait_interval = cfg.CONF.deployer.wait_interval
         growth_factor = cfg.CONF.deployer.growth_factor
@@ -577,7 +671,7 @@ class Handler(object):
             time.sleep(wait_interval)
             wait_interval *= growth_factor
             try:
-                stack = osc.heat().stacks.get(stack_id)
+                stack = heat_clnt.stacks.get(stack_id)
             except Exception as e:
                 LOG.exception(e)
                 continue
@@ -655,7 +749,7 @@ class Handler(object):
             time.sleep(1)
 
         if du_is_up:
-            to_update = {'status': STATES.READY}
+            to_update = {'status': STATES.DEPLOYMENT_COMPLETE}
         else:
             to_update = {'status': STATES.ERROR_CODE_DEPLOYMENT}
             lg_msg = ("App deployment error: unreachable server or port, "
